@@ -5,14 +5,14 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-appconfig", "1.63.0", __name__[0:-6], "aws-appconfig@1.63.0.jsii.tgz"
+    "@aws-cdk/aws-appconfig", "1.64.1", __name__[0:-6], "aws-appconfig@1.64.1.jsii.tgz"
 )
 
 __all__ = [
